aboutsummaryrefslogtreecommitdiffhomepage
path: root/isar/isar-find-theorems.el
diff options
context:
space:
mode:
authorGravatar weber <>2007-05-11 17:46:42 +0000
committerGravatar weber <>2007-05-11 17:46:42 +0000
commit2266598d4bf11cda967951cfb9ba29297f779b4d (patch)
tree3a776136f9621ccdbff75de8c9cbebed736911e6 /isar/isar-find-theorems.el
parentfc87a12adf5e07e262fbe5209aa75d88812c0474 (diff)
Fix rename
Diffstat (limited to 'isar/isar-find-theorems.el')
-rw-r--r--isar/isar-find-theorems.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/isar/isar-find-theorems.el b/isar/isar-find-theorems.el
index 7be415a8..383fd727 100644
--- a/isar/isar-find-theorems.el
+++ b/isar/isar-find-theorems.el
@@ -18,15 +18,15 @@
(defun isar-find-theorems-minibuffer ()
"Search for items containing given constants (using the minibuffer)."
(interactive)
- (let ((isar-find-theorems-command "find_theorems %s"))
- (call-interactively 'isar-find-theorems))
+ (let ((proof-find-theorems-command "find_theorems %s"))
+ (call-interactively 'proof-find-theorems))
'(nil))
;; isar-find-theorems-form (just like isar-find-theorems-minibuffer) can be
;; called interactively, and can be used as a value for
;; isar-find-theorems-command (returning '(nil) means that the actual
;; "find_theorems" command will NOT be issued to Isabelle by
;; isar-find-theorems in this case, but only later on by a handler function
;; for the form's "Find" button)
(defun isar-find-theorems-form ()
@@ -18,15 +18,15 @@
;; isar-find-theorems-form (just like isar-find-theorems-minibuffer) can be
;; called interactively, and can be used as a value for
-;; isar-find-theorems-command (returning '(nil) means that the actual
+;; proof-find-theorems-command (returning '(nil) means that the actual
;; "find_theorems" command will NOT be issued to Isabelle by
@@ -18,15 +18,15 @@
;; "find_theorems" command will NOT be issued to Isabelle by
-;; isar-find-theorems in this case, but only later on by a handler function
+;; proof-find-theorems in this case, but only later on by a handler function
;; for the form's "Find" button)
(defun isar-find-theorems-form ()